==> libxpertmass_1.3.0.orig.tar.gz: libxpertmass-1.3.0/doc/devdoc/libXpertMassCore.h <==
#include "MsXpS/export-import-config.h"
#include "MsXpS/libXpertMassCore/CalcOptions.hpp"
#include "MsXpS/libXpertMassCore/ChemicalGroup.hpp"
#include "MsXpS/libXpertMassCore/ChemicalGroupRule.hpp"
#include "MsXpS/libXpertMassCore/CleavageAgent.hpp"
#include "MsXpS/libXpertMassCore/CleavageConfig.hpp"
#include "MsXpS/libXpertMassCore/CleavageMotif.hpp"
#include "MsXpS/libXpertMassCore/CleavageRule.hpp"
#include "MsXpS/libXpertMassCore/Cleaver.hpp"
#include "MsXpS/libXpertMassCore/CrossLinkedRegion.hpp"
#include "MsXpS/libXpertMassCore/CrossLinker.hpp"
#include "MsXpS/libXpertMassCore/CrossLink.hpp"
#include "MsXpS/libXpertMassCore/Formula.hpp"
#include "MsXpS/libXpertMassCore/FragmentationConfig.hpp"
#include "MsXpS/libXpertMassCore/FragmentationPathway.hpp"
#include "MsXpS/libXpertMassCore/FragmentationRule.hpp"
#include "MsXpS/libXpertMassCore/Fragmenter.hpp"
#include "MsXpS/libXpertMassCore/globals.hpp"
#include "MsXpS/libXpertMassCore/IndexRangeCollection.hpp"
#include "MsXpS/libXpertMassCore/Ionizer.hpp"
#include "MsXpS/libXpertMassCore/Isotope.hpp"
#include "MsXpS/libXpertMassCore/IsotopicClusterGenerator.hpp"
#include "MsXpS/libXpertMassCore/IsotopicClusterShaper.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataBaseHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataManualConfigHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataUserConfigHandler.hpp"
#include "MsXpS/libXpertMassCore/MassCollection.hpp"
#include "MsXpS/libXpertMassCore/MassDataCborBaseHandler.hpp"
#include "MsXpS/libXpertMassCore/MassDataCborMassSpectrumHandler.hpp"
#include "MsXpS/libXpertMassCore/MassDataClient.hpp"
#include "MsXpS/libXpertMassCore/MassDataServer.hpp"
#include "MsXpS/libXpertMassCore/MassDataServerThread.hpp"
#include "MsXpS/libXpertMassCore/MassPeakShaperConfig.hpp"
#include "MsXpS/libXpertMassCore/MassPeakShaper.hpp"
#include "MsXpS/libXpertMassCore/Modif.hpp"
#include "MsXpS/libXpertMassCore/MonomerDictionary.hpp"
#include "MsXpS/libXpertMassCore/Monomer.hpp"
#include "MsXpS/libXpertMassCore/OligomerCollection.hpp"
#include "MsXpS/libXpertMassCore/Oligomer.hpp"
#include "MsXpS/libXpertMassCore/OligomerPaier.hpp"
#include "MsXpS/libXpertMassCore/PkaPhPiDataParser.hpp"
#include "MsXpS/libXpertMassCore/PkaPhPi.hpp"
#include "MsXpS/libXpertMassCore/PolChemDef.hpp"
#include "MsXpS/libXpertMassCore/PolChemDefSpec.hpp"
#include "MsXpS/libXpertMassCore/Polymer.hpp"
#include "MsXpS/libXpertMassCore/Prop.hpp"
#include "MsXpS/libXpertMassCore/PropListHolder.hpp"
#include "MsXpS/libXpertMassCore/Sequence.hpp"
#include "MsXpS/libXpertMassCore/Utils.hpp"
#include "MsXpS/libXpertMassCore/XpertMassJsQml.hpp"

==> libxpertmass_1.4.0.orig.tar.gz: libxpertmass-1.4.0/doc/devdoc/libXpertMassCore.h <==
#include "MsXpS/export-import-config.h"
#include "MsXpS/libXpertMassCore/CalcOptions.hpp"
#include "MsXpS/libXpertMassCore/ChemicalGroup.hpp"
#include "MsXpS/libXpertMassCore/ChemicalGroupRule.hpp"
#include "MsXpS/libXpertMassCore/CleavageAgent.hpp"
#include "MsXpS/libXpertMassCore/CleavageConfig.hpp"
#include "MsXpS/libXpertMassCore/CleavageMotif.hpp"
#include "MsXpS/libXpertMassCore/CleavageRule.hpp"
#include "MsXpS/libXpertMassCore/Cleaver.hpp"
#include "MsXpS/libXpertMassCore/CrossLinkedRegion.hpp"
#include "MsXpS/libXpertMassCore/CrossLinker.hpp"
#include "MsXpS/libXpertMassCore/CrossLink.hpp"
#include "MsXpS/libXpertMassCore/Formula.hpp"
#include "MsXpS/libXpertMassCore/FragmentationConfig.hpp"
#include "MsXpS/libXpertMassCore/FragmentationPathway.hpp"
#include "MsXpS/libXpertMassCore/FragmentationRule.hpp"
#include "MsXpS/libXpertMassCore/Fragmenter.hpp"
#include "MsXpS/libXpertMassCore/globals.hpp"
#include "MsXpS/libXpertMassCore/IndexRangeCollection.hpp"
#include "MsXpS/libXpertMassCore/Ionizer.hpp"
#include "MsXpS/libXpertMassCore/Isotope.hpp"
#include "MsXpS/libXpertMassCore/IsotopicClusterGenerator.hpp"
#include "MsXpS/libXpertMassCore/IsotopicClusterShaper.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataBaseHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataManualConfigHandler.hpp"
#include "MsXpS/libXpertMassCore/IsotopicDataUserConfigHandler.hpp"
#include "MsXpS/libXpertMassCore/MassCollection.hpp"
#include "MsXpS/libXpertMassCore/MassDataCborBaseHandler.hpp"
#include "MsXpS/libXpertMassCore/MassDataCborMassSpectrumHandler.hpp"
#include "MsXpS/libXpertMassCore/MassDataClient.hpp"
#include "MsXpS/libXpertMassCore/MassDataServer.hpp"
#include "MsXpS/libXpertMassCore/MassPeakShaperConfig.hpp"
#include "MsXpS/libXpertMassCore/MassPeakShaper.hpp"
#include "MsXpS/libXpertMassCore/Modif.hpp"
#include "MsXpS/libXpertMassCore/MonomerDictionary.hpp"
#include "MsXpS/libXpertMassCore/Monomer.hpp"
#include "MsXpS/libXpertMassCore/OligomerCollection.hpp"
#include "MsXpS/libXpertMassCore/Oligomer.hpp"
#include "MsXpS/libXpertMassCore/OligomerPair.hpp"
#include "MsXpS/libXpertMassCore/PkaPhPiDataParser.hpp"
#include "MsXpS/libXpertMassCore/PkaPhPi.hpp"
#include "MsXpS/libXpertMassCore/PolChemDef.hpp"
#include "MsXpS/libXpertMassCore/PolChemDefSpec.hpp"
#include "MsXpS/libXpertMassCore/Polymer.hpp"
#include "MsXpS/libXpertMassCore/Prop.hpp"
#include "MsXpS/libXpertMassCore/PropListHolder.hpp"
#include "MsXpS/libXpertMassCore/Sequence.hpp"
#include "MsXpS/libXpertMassCore/Utils.hpp"
#include "MsXpS/libXpertMassCore/XpertMassCoreJavaScript.hpp"
